@@ -3,7 +3,7 @@
 # pylint: disable=duplicate-code
 import datetime
 
-import requests_cache
+from scrapesession.scrapesession import ScrapeSession  # type: ignore
 
 from ...cache import MEMORY
 from ..google.google_address_model import create_google_address_model
@@ -13,7 +13,7 @@ from ..venue_model import VenueModel
 @MEMORY.cache(ignore=["session"])
 def create_aussportsbetting_venue_model(
     venue: str,
-    session: requests_cache.CachedSession,
+    session: ScrapeSession,
     dt: datetime.datetime,
     version: str,
 ) -> VenueModel:
